@@ -1,20 +1,7 @@
-/* Portions Copyright (C) 2009-2022 Greenbone Networks GmbH
- * Based on work Copyright (C) 2002 - 2004 Tenable Network Security
+/* SPDX-FileCopyrightText: 2023 Greenbone AG
+ * SPDX-FileCopyrightText: 2002-2004 Tenable Network Security
  *
  * SPDX-License-Identifier: GPL-2.0-only
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * version 2 as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #define _GNU_SOURCE
@@ -1667,7 +1654,7 @@ exec_nasl_script (struct script_infos *script_infos, int mode)
   else
     ctx.kb = plug_get_kb (script_infos);
 
-  if (init_nasl_ctx (&ctx, name) == 0)
+  if (init_nasl_ctx (&ctx, NULL, name) == 0)
     {
       err = naslparse (&ctx, &error_counter);
       if (err != 0 || error_counter > 0)
