@@ -1,19 +1,7 @@
-/* Based on work Copyright (C) 2002 - 2004 Tenable Network Security
+/* SPDX-FileCopyrightText: 2023 Greenbone AG
+ * SPDX-FileCopyrightText: 2002-2004 Tenable Network Security
  *
  * SPDX-License-Identifier: GPL-2.0-only
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * version 2 as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /**
@@ -39,6 +27,7 @@
 #include <arpa/inet.h> /* for inet_aton */
 #include <ctype.h>     /* for isprint */
 #include <pcap.h>      /* for PCAP_ERRBUF_SIZE */
+#include <stddef.h>
 #include <stdlib.h>    /* for rand */
 #include <string.h>    /* for bcopy */
 #include <sys/param.h>
@@ -135,7 +124,7 @@ forge_ip_v6_packet (lex_ctxt *lexic)
   struct script_infos *script_infos = lexic->script_infos;
   struct in6_addr *dst_addr;
   char *data;
-  int data_len;
+  size_t data_len;
   int version;
   int tc;
   int fl;
@@ -307,7 +296,7 @@ tree_cell *
 set_ip_v6_elements (lex_ctxt *lexic)
 {
   struct ip6_hdr *o_pkt = (struct ip6_hdr *) get_str_var_by_name (lexic, "ip6");
-  int size = get_var_size_by_name (lexic, "ip6");
+  size_t size = get_var_size_by_name (lexic, "ip6");
   tree_cell *retc;
   struct ip6_hdr *pkt;
   char *s;
@@ -409,11 +398,11 @@ insert_ip_v6_options (lex_ctxt *lexic)
   int code = get_int_var_by_name (lexic, "code", 0);
   int len = get_int_var_by_name (lexic, "length", 0);
   char *value = get_str_var_by_name (lexic, "value");
-  int value_size = get_var_size_by_name (lexic, "value");
+  size_t value_size = get_var_size_by_name (lexic, "value");
   tree_cell *retc;
   struct ip6_hdr *new_packet;
   char *p;
-  int size = get_var_size_by_name (lexic, "ip6");
+  size_t size = get_var_size_by_name (lexic, "ip6");
   u_char uc_code, uc_len;
   int pad_len;
   char zero = '0';
@@ -543,10 +532,10 @@ forge_tcp_v6_packet (lex_ctxt *lexic)
 {
   tree_cell *retc;
   char *data;
-  int len;
+  size_t len;
   struct ip6_hdr *ip6, *tcp_packet;
   struct tcphdr *tcp;
-  int ipsz;
+  size_t ipsz;
 
   ip6 = (struct ip6_hdr *) get_str_var_by_name (lexic, "ip6");
   if (ip6 == NULL)
@@ -631,7 +620,7 @@ get_tcp_v6_element (lex_ctxt *lexic)
 {
   u_char *packet = (u_char *) get_str_var_by_name (lexic, "tcp");
   struct ip6_hdr *ip6;
-  int ipsz;
+  long int ipsz;
   struct tcphdr *tcp;
   char *element;
   int ret;
@@ -788,7 +777,7 @@ get_tcp_v6_option (lex_ctxt *lexic)
 {
   u_char *packet = (u_char *) get_str_var_by_name (lexic, "tcp");
   struct ip6_hdr *ip6;
-  int ipsz;
+  size_t ipsz;
   struct tcphdr *tcp;
   char *options;
   int opt;
@@ -907,11 +896,11 @@ set_tcp_v6_elements (lex_ctxt *lexic)
 {
   char *pkt = get_str_var_by_name (lexic, "tcp");
   struct ip6_hdr *ip6 = (struct ip6_hdr *) pkt;
-  int pktsz = get_var_size_by_name (lexic, "tcp");
+  size_t pktsz = get_var_size_by_name (lexic, "tcp");
   struct tcphdr *tcp;
   tree_cell *retc;
   char *data = get_str_var_by_name (lexic, "data");
-  int data_len = get_var_size_by_name (lexic, "data");
+  size_t data_len = get_var_size_by_name (lexic, "data");
   char *npkt;
 
   if (pkt == NULL)
@@ -1012,11 +1001,11 @@ insert_tcp_v6_options (lex_ctxt *lexic)
 {
   char *pkt = get_str_var_by_name (lexic, "tcp");
   struct ip6_hdr *ip6 = (struct ip6_hdr *) pkt;
-  int pktsz = get_var_size_by_name (lexic, "tcp");
+  size_t pktsz = get_var_size_by_name (lexic, "tcp");
   struct tcphdr *tcp;
   tree_cell *retc;
   char *data = get_str_var_by_name (lexic, "data");
-  int data_len = get_var_size_by_name (lexic, "data");
+  size_t data_len = get_var_size_by_name (lexic, "data");
   char *npkt;
   int tcp_opt, tcp_opt_val, tcp_opt_val2;
   int current_opt_len, total_opt_len, opt_size_allocated;
@@ -1412,7 +1401,7 @@ forge_udp_v6_packet (lex_ctxt *lexic)
   if (ip6 != NULL)
     {
       char *data = get_str_var_by_name (lexic, "data");
-      int data_len = get_var_size_by_name (lexic, "data");
+      size_t data_len = get_var_size_by_name (lexic, "data");
       u_char *pkt;
       struct ip6_hdr *udp_packet;
       struct udphdr *udp;
@@ -1493,7 +1482,7 @@ get_udp_v6_element (lex_ctxt *lexic)
   tree_cell *retc;
   char *udp;
   char *element;
-  unsigned int ipsz;
+  size_t ipsz;
   struct udphdr *udphdr;
   int ret;
 
@@ -1563,9 +1552,9 @@ tree_cell *
 set_udp_v6_elements (lex_ctxt *lexic)
 {
   struct ip6_hdr *ip6 = (struct ip6_hdr *) get_str_var_by_name (lexic, "udp");
-  unsigned int sz = get_var_size_by_name (lexic, "udp");
+  size_t sz = get_var_size_by_name (lexic, "udp");
   char *data = get_str_var_by_name (lexic, "data");
-  int data_len = get_var_size_by_name (lexic, "data");
+  size_t data_len = get_var_size_by_name (lexic, "data");
 
   if (ip6 != NULL)
     {
@@ -1739,7 +1728,7 @@ forge_icmp_v6_packet (lex_ctxt *lexic)
   tree_cell *retc = NULL;
   struct ip6_hdr *ip6;
   struct ip6_hdr *ip6_icmp;
-  int ip6_sz, size = 0, sz = 0;
+  size_t ip6_sz, size = 0, sz = 0;
   struct icmp6_hdr *icmp;
   struct nd_router_solicit *routersolicit = NULL;
   struct nd_router_advert *routeradvert = NULL;
@@ -1747,7 +1736,7 @@ forge_icmp_v6_packet (lex_ctxt *lexic)
   struct nd_neighbor_advert *neighboradvert = NULL;
 
   char *data, *p;
-  int len;
+  size_t len;
   u_char *pkt;
   int t;
   ip6 = (struct ip6_hdr *) get_str_var_by_name (lexic, "ip6");
@@ -2126,14 +2115,14 @@ forge_igmp_v6_packet (lex_ctxt *lexic)
   if (ip6 != NULL)
     {
       char *data = get_str_var_by_name (lexic, "data");
-      int len = data ? get_var_size_by_name (lexic, "data") : 0;
+      size_t len = data ? get_var_size_by_name (lexic, "data") : 0;
       u_char *pkt = g_malloc0 (sizeof (struct igmp6_hdr) + 40 + len);
       struct ip6_hdr *ip6_igmp = (struct ip6_hdr *) pkt;
       struct igmp6_hdr *igmp;
       char *p;
       char *grp;
       tree_cell *retc;
-      int ipsz = get_var_size_by_name (lexic, "ip6");
+      size_t ipsz = get_var_size_by_name (lexic, "ip6");
 
       bcopy (ip6, ip6_igmp, ipsz);
 
@@ -2341,12 +2330,14 @@ nasl_send_v6packet (lex_ctxt *lexic)
   struct sockaddr_in6 sockaddr;
   char *ip = NULL;
   struct ip6_hdr *sip = NULL;
-  int vi = 0, b = 0, len = 0;
+  int vi = 0;
+  ssize_t b = 0;
+  size_t len = 0;
   int soc;
   int use_pcap = get_int_var_by_name (lexic, "pcap_active", 1);
   int to = get_int_var_by_name (lexic, "pcap_timeout", 5);
   char *filter = get_str_var_by_name (lexic, "pcap_filter");
-  int dfl_len = get_int_var_by_name (lexic, "length", -1);
+  size_t dfl_len = get_int_var_by_name (lexic, "length", -1);
   struct script_infos *script_infos = lexic->script_infos;
   struct in6_addr *dstip = plug_get_host_ip (script_infos);
   int opt_on = 1;
@@ -2366,10 +2357,10 @@ nasl_send_v6packet (lex_ctxt *lexic)
   while ((ip = get_str_var_by_num (lexic, vi)) != NULL)
     {
       allow_multicast = get_int_var_by_name (lexic, "allow_multicast", 0);
-      int sz = get_var_size_by_num (lexic, vi);
+      size_t sz = get_var_size_by_num (lexic, vi);
       vi++;
 
-      if ((unsigned int) sz < sizeof (struct ip6_hdr))
+      if (sz < sizeof (struct ip6_hdr))
         {
           nasl_perror (lexic, "send_v6packet: packet is too short\n");
           continue;
