@@ -419,9 +419,8 @@ read_ipc (struct attack_start_args *args, struct ipc_context *ctx)
 
   while ((results = ipc_retrieve (ctx, IPC_MAIN)) != NULL)
     {
-      int len = 0;
-      int pos = 0;
-      for (int j = 0; results[j] != '\0'; j++)
+      size_t len, pos = 0;
+      for (size_t j = 0; results[j] != '\0'; j++)
         if (results[j] == '}')
           {
             gchar *message = NULL;
@@ -429,7 +428,6 @@ read_ipc (struct attack_start_args *args, struct ipc_context *ctx)
             message = g_malloc0 (sizeof (gchar) * (len + 1));
             memcpy (message, &results[pos], len);
             pos = j + 1;
-            len = 0;
             ipc_msg_flag |= process_ipc_data (args, message);
             g_free (message);
           }
